@@ -2,7 +2,7 @@
 #
 #  Copyright (c) Schneider Electric Industries, 2019. All right reserved.
 
-from pyfields import field, init_fields, autofields
+from pyfields import field, init_fields, autofields, autoclass
 
 
 def test_issue_51():
@@ -45,3 +45,18 @@ def test_issue_73_cross_ref():
     # note: we have to define the classes outside the function for the cross-ref to work
     # indeed typing.get_type_hints() will only access the globals of the defining module
     return A, B
+
+
+def test_issue_81():
+
+    # note that the issue comes from autofields actually, but it was detected using autoclass
+
+    @autoclass
+    class A:
+        a: int = 1
+
+    @autoclass
+    class B(A):
+        b = 0
+
+    return A, B
